"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _awsSdk = require("aws-sdk");

var _bluebird = _interopRequireDefault(require("bluebird"));

/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */
_awsSdk.config.setPromisesDependency(_bluebird.default);

class Connector {
  constructor({
    debug,
    bucketName = process.env.BUCKET_NAME,
    timeout = Number(process.env.S3_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = msg => debug('%j', msg);

    this.bucketName = bucketName || 'undefined';
    this.bucket = new _awsSdk.S3({
      httpOptions: {
        timeout,
        connectTimeout: timeout
      },
      logger: {
        log:
        /* istanbul ignore next */
        msg => debug('%s', msg.replace(/\n/g, '\r'))
      }
    });
  }

  putObject(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this.bucket.putObject(params).promise().tap(this.debug).tapCatch(this.debug);
  }

  deleteObject(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this.bucket.deleteObject(params).promise().tap(this.debug).tapCatch(this.debug);
  }

  getObject(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this.bucket.getObject(params).promise().tap(this.debug).tapCatch(this.debug);
  }

  listObjects(inputParams) {
    const params = {
      Bucket: this.bucketName,
      ...inputParams
    };
    return this.bucket.listObjectsV2(params).promise().tap(this.debug).tapCatch(this.debug);
  }

}

var _default = Connector;
exports.default = _default;