"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.toFirehoseRecord = exports.sendToFirehose = void 0;

var _highland = _interopRequireDefault(require("highland"));

var _firehose = _interopRequireDefault(require("../connectors/firehose"));

var _batch = require("./batch");

var _faults = require("./faults");

var _print = require("./print");

var _compression = require("./compression");

const sendToFirehose = ({
  debug = (0, _print.debug)('firehose'),
  deliveryStreamName = process.env.DELIVERY_STREAM_NAME,
  eventField = 'event',
  batchSize = Number(process.env.FIREHOSE_BATCH_SIZE) || Number(process.env.BATCH_SIZE) || 25,
  parallel = Number(process.env.FIREHOSE_PARALLEL) || Number(process.env.PARALLEL) || 8,
  handleErrors = true,
  ...opt
} = {}) => {
  const connector = new _firehose.default({
    debug,
    deliveryStreamName
  });

  const toInputParams = batchUow => ({ ...batchUow,
    inputParams: {
      Records: batchUow.batch.map(uow => toFirehoseRecord(uow[eventField], opt))
    }
  });

  const putRecordBatch = batchUow => {
    const p = connector.putRecordBatch(batchUow.inputParams).then(putResponse => ({ ...batchUow,
      putResponse
    })).catch((0, _faults.rejectWithFault)(batchUow, !handleErrors)); // .then(handleFailedPutCount);

    return (0, _highland.default)(p); // wrap promise in a stream
  };

  return s => s.batch(batchSize).map(_batch.toBatchUow).map(toInputParams).map(putRecordBatch).parallel(parallel).flatMap(_batch.unBatchUow); // for cleaner logging and testing
}; // TODO
// const handleFailedPutCount = (putResponse) => {
//   if (putResponse.FailedPutCount > 0) {
//     // const e = new Error();
//     // TODO
//     // raise error to resend (will create dups) or
//     // resend here (will eventually timeout) and/or
//     // raise fault with failed events
//   }
//   return putResponse;
// };


exports.sendToFirehose = sendToFirehose;

const toFirehoseRecord = (e, opt) => ({
  Data: Buffer.from(`${JSON.stringify(e, (0, _compression.compress)(opt))}\n`)
});

exports.toFirehoseRecord = toFirehoseRecord;